test

# configurator report¶

This notebook contains the automatic `configurator` report based on preliminary PE results.

Data provenance

PE summary file | /Users/hestelles/Downloads/posterior_samples-GW191109_final.h5
Data set | SEOBNRv5PHM
md5sum of file | 72ce4d48c94994e0c7a042d9c04339b4
git revision of data | N/A__DIRTY

Settings

$f_{\rm low}$ | 20.0 Hz
$f_{\rm ref}$ | 20.0 Hz
Max $\ell$ for Nyquist check | 3
Tolerance for railing | 2.0
nbins for railing | 50

## Automatically generated analysis¶

- **Equal masses are excluded at high confidence for this event!

**

- **The median $\chi_{

m eff}<0.1$! The median $\chi_{p}>0.6$, highly precessing event?**

    2023-04-12  09:47:51 PESummary WARNING : Could not find f_final in input file and one was not passed from the command line. Using 1024.0Hz as default
    2023-04-12  09:47:51 PESummary WARNING : Could not find delta_f in input file and one was not passed from the command line. Using 0.00390625Hz as default
    2023-04-12  09:47:51 PESummary WARNING : Could not find minimum frequency in input file and one was not passed from the command line. Using 20.0Hz as default
    2023-04-12  09:47:53 PESummary WARNING : Could not find f_final in input file and one was not passed from the command line. Using 1024.0Hz as default
    2023-04-12  09:47:53 PESummary WARNING : Could not find delta_f in input file and one was not passed from the command line. Using 0.00390625Hz as default
    2023-04-12  09:47:53 PESummary WARNING : Could not find minimum frequency in input file and one was not passed from the command line. Using 20.0Hz as default
    2023-04-12  09:47:54 PESummary WARNING : Could not find f_final in input file and one was not passed from the command line. Using 1024.0Hz as default
    2023-04-12  09:47:54 PESummary WARNING : Could not find delta_f in input file and one was not passed from the command line. Using 0.00390625Hz as default
    2023-04-12  09:47:54 PESummary WARNING : Could not find minimum frequency in input file and one was not passed from the command line. Using 20.0Hz as default

## Summary of posterior sample parameters¶

| $\mathcal{M}$ | $M_{\rm total}$ | $q$ | $d_{L}$ | $\chi_{1z}$ | $\chi_{2z}$
--- | --- | --- | --- | --- | --- | ---
count | 20000.000000 | 20000.000000 | 20000.000000 | 20000.000000 | 20000.000000 | 20000.000000
mean | 58.186813 | 137.748587 | 0.668517 | 973.291138 | -0.529751 | -0.091799
std | 3.804646 | 7.139722 | 0.118778 | 356.051637 | 0.200602 | 0.288842
min | 37.689124 | 107.487701 | 0.217817 | 105.869872 | -0.986634 | -0.969572
25% | 55.814919 | 133.026042 | 0.585290 | 746.913884 | -0.675039 | -0.268373
50% | 58.368684 | 137.878864 | 0.663153 | 890.434401 | -0.545213 | -0.050609
75% | 60.750040 | 142.487467 | 0.746192 | 1100.029739 | -0.404481 | 0.080035
max | 71.587694 | 170.507628 | 0.999228 | 2982.683410 | 0.530185 | 0.929540

## Posterior railing visual check¶

Automatic checks on railing. Note that the recommendations are ad-hoc and may not result in posteriors not being cut off.

|  | Recommendation
--- | --- | ---
chirp_mass | PASSED |
distance | PASSED |
mass_ratio | PASSED |

Plot of selected posterior parameters. All masses are in the detector frame. The red dashed lines show the proposed $\mathcal{M}$ bounds,[30.1513,85.9052]

## MECO frequency check¶

The reference frequency is shown as a dashed green vertical line. If the reference frequency has been modified by the MECO test, the input value appears in red and the new value in green.

|  | Recommendation
--- | --- | ---
f_ref | FAILED. f_ref has been overwritten to a safe value. |

## Recommended settings¶

seglen | 4.0 sec.
srate | 1024
$f_{\rm start}$ | 8.945 Hz
$f_{\rm ref}$ | 14.8613 Hz
$\mathcal{M}$ bounds | [30.1513,85.9052]

## Extra information¶

Date | 2023-04-12 09:47:48.056008
Script revision | ad853bac7cca41f13b704b059414ff09d8157603__DIRTY
Complete arguments | Namespace(output_dir='examples/test_GW191109', HM=True, q_min=None, ell_max=3, tolerance=2.0, nbins=50, flow=20.0, f_ref=20.0, bounds_tol=0.2, json_file='test.json', report_file='test.pdf', override_safeties=False, debug=False, include_dL_recommendations=False)